#!/usr/bin/env python3
#
# ShotHub API sample script #1: Print the folder structure for one or more projects
#
# (c) 2022 - 2023 Pomfort GmbH, https://pomfort.com/
#
# To use, customize the configuration section below and run it. Make sure that your script user is in at least one
# project, or the script will not show any useful output!
#
# No pip modules are required.

import requests

base_url = "https://api.pomfort.com/sh"

# config - please enter your credentials here
creds = {
    "scriptId": "62c41fb517bb6d5f526d162a/DemoScript",
    "scriptKey": "dwdussBFMMzGsdo3cgBgZS8aNVXmMxbc"
}


def print_folder(folder, recursion_level = 0):
    padding = recursion_level * "  "
    print(padding + "+ " + folder["name"])
    for child in folder["children"]:
        print_folder(child, recursion_level + 1)


def print_project_folder_tree(project, headers):
    # load folder tree
    fres = requests.get(base_url + "/v1.0/folders-tree/" + project["id"], headers=headers)
    if fres.status_code != 200:
        print('ERROR: Folder tree request returned status code', fres.status_code)
        exit(1)

    print()
    print("=== PROJECT " + project["name"] + " ===")
    print()

    for folder in fres.json():
        print_folder(folder)


def main():
    # get a JWT token
    res = requests.post(base_url + "/authenticate", json=creds)

    if res.status_code != 200:
        print('ERROR: login request returned status code', res.status_code)
        exit(1)

    token = res.json()['id_token']
    headers = {
        'Authorization': 'Bearer ' + token
    }

    # get project list
    res = requests.get(base_url + "/v1.0/projects?page=0&take=50", headers=headers)
    if res.status_code != 200:
        print('ERROR: Project list request returned status code', res.status_code)
        exit(1)

    project_list = res.json()

    for project in project_list:
        print_project_folder_tree(project, headers)


main()
